@@ -68,13 +68,14 @@ def preprocess_dataset(X, X_names, pres = None):
         pre = 'diff' : first-order op. We use io.pre.diff_dataset()
         pre = 'threshold' : call io.pre.x_thresholding()
         pre = 'peak_normalize' / 'rowvec_normalize' : call io.pre.x_normalize()
+        pre = 'baseline_removal' : call io.pre.x_baseline_removal()
         
         default is [] or None. 
 
     Remarks
     -------
     Default preprocessing parameters for MALDI-TOF data:
-    [('threshold', 10), ('max', 0.01), ('peak_normalize', 1000)]
+    [('baseline_removal', 1e-3), ('threshold', 10), ('max', 0.01), ('peak_normalize', 1000)]
     '''
     IPython.display.display(IPython.display.HTML('<hr/><h2>每个样本的预处理 Row-wise Preprocessing </h2>'))
     
@@ -85,7 +86,10 @@ def preprocess_dataset(X, X_names, pres = None):
         pre_type, pre_param = pre        
         IPython.display.display(IPython.display.HTML('<h3>' + pre_type + '</h3>'))
 
-        if pre_type == 'threshold':
+        if pre_type == 'baseline_removal':
+            X = io.pre.x_baseline_removal(X, p = pre_param)  # use default lambda = 1e8
+            print('消除基线飘移: baseline removal (residual penalty asymetry = ' + str(pre_param) + ')')
+        elif pre_type == 'threshold':
             X = io.pre.x_thresholding(X, pre_param)
             print('阈值预处理（消除背景噪声）: threshold = ' + str(pre_param))
         elif pre_type in ['max', 'sum', 'rect', 'tri', 'mean']:
